@@ -191,7 +191,6 @@ class Circle(Model):
                               null=True, blank=True)
 
     class Meta(Model.Meta):
-        nested_fields_exclude = ["team"]
         anonymous_perms = ['view', 'add', 'delete', 'add', 'change', 'control']
         authenticated_perms = ["inherit"]
         rdf_type = 'hd:circle'
@@ -223,10 +222,12 @@ class Project(Model):
 
 
 class DateModel(Model):
+    excluded = models.CharField(max_length=255, null=True, default='test')
     value = models.DateField()
 
     class Meta(Model.Meta):
         rdf_type = "hd:date"
+        serializer_fields_exclude = ['excluded']
 
 
 class DateChild(Model):
